# coding: utf-8

"""
    Ringer Business API - Call Blocking Management

    This API provides endpoints for managing call blocking rules on a specific site. Call blocking allows customers to prevent inbound calls from specified numbers to certain extensions or all extensions on a site. When a blocked number attempts to call, they will typically receive a busy tone.  Functionality includes: - Listing all call block rules for a site. - Creating a new call block rule. - Retrieving details of a specific call block rule. - Updating an existing call block rule. - Deleting a call block rule. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt
from typing_extensions import Annotated
from ringer_business.models.call_block_create_request import CallBlockCreateRequest
from ringer_business.models.call_block_list_response import CallBlockListResponse
from ringer_business.models.call_block_response import CallBlockResponse
from ringer_business.models.call_block_update_request import CallBlockUpdateRequest

from ringer_business.api_client import ApiClient, RequestSerialized
from ringer_business.api_response import ApiResponse
from ringer_business.rest import RESTResponseType


class CallBlockingApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_site_call_block(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        call_block_create_request: Annotated[CallBlockCreateRequest, Field(description="Details of the call block rule to create.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CallBlockResponse:
        """Create a New Call Block Rule

        Adds a new call blocking rule to the specified site.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param call_block_create_request: Details of the call block rule to create. (required)
        :type call_block_create_request: CallBlockCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_site_call_block_serialize(
            site_id=site_id,
            call_block_create_request=call_block_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "CallBlockResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '409': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_site_call_block_with_http_info(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        call_block_create_request: Annotated[CallBlockCreateRequest, Field(description="Details of the call block rule to create.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CallBlockResponse]:
        """Create a New Call Block Rule

        Adds a new call blocking rule to the specified site.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param call_block_create_request: Details of the call block rule to create. (required)
        :type call_block_create_request: CallBlockCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_site_call_block_serialize(
            site_id=site_id,
            call_block_create_request=call_block_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "CallBlockResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '409': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_site_call_block_without_preload_content(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        call_block_create_request: Annotated[CallBlockCreateRequest, Field(description="Details of the call block rule to create.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create a New Call Block Rule

        Adds a new call blocking rule to the specified site.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param call_block_create_request: Details of the call block rule to create. (required)
        :type call_block_create_request: CallBlockCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_site_call_block_serialize(
            site_id=site_id,
            call_block_create_request=call_block_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "CallBlockResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '409': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_site_call_block_serialize(
        self,
        site_id,
        call_block_create_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['siteId'] = site_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if call_block_create_request is not None:
            _body_params = call_block_create_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/sites/{siteId}/call-blocks',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_site_call_block_by_id(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        call_block_id: Annotated[StrictInt, Field(description="The unique identifier of the call block rule.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete a Call Block Rule

        Permanently deletes a specific call blocking rule by its ID.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param call_block_id: The unique identifier of the call block rule. (required)
        :type call_block_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_site_call_block_by_id_serialize(
            site_id=site_id,
            call_block_id=call_block_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_site_call_block_by_id_with_http_info(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        call_block_id: Annotated[StrictInt, Field(description="The unique identifier of the call block rule.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete a Call Block Rule

        Permanently deletes a specific call blocking rule by its ID.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param call_block_id: The unique identifier of the call block rule. (required)
        :type call_block_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_site_call_block_by_id_serialize(
            site_id=site_id,
            call_block_id=call_block_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_site_call_block_by_id_without_preload_content(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        call_block_id: Annotated[StrictInt, Field(description="The unique identifier of the call block rule.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete a Call Block Rule

        Permanently deletes a specific call blocking rule by its ID.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param call_block_id: The unique identifier of the call block rule. (required)
        :type call_block_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_site_call_block_by_id_serialize(
            site_id=site_id,
            call_block_id=call_block_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_site_call_block_by_id_serialize(
        self,
        site_id,
        call_block_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['siteId'] = site_id
        if call_block_id is not None:
            _path_params['callBlockId'] = call_block_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/sites/{siteId}/call-blocks/{callBlockId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_site_call_block_by_id(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        call_block_id: Annotated[StrictInt, Field(description="The unique identifier of the call block rule.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CallBlockResponse:
        """Get Call Block Rule Details

        Retrieves detailed information for a specific call blocking rule by its ID.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param call_block_id: The unique identifier of the call block rule. (required)
        :type call_block_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_site_call_block_by_id_serialize(
            site_id=site_id,
            call_block_id=call_block_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CallBlockResponse",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_site_call_block_by_id_with_http_info(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        call_block_id: Annotated[StrictInt, Field(description="The unique identifier of the call block rule.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CallBlockResponse]:
        """Get Call Block Rule Details

        Retrieves detailed information for a specific call blocking rule by its ID.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param call_block_id: The unique identifier of the call block rule. (required)
        :type call_block_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_site_call_block_by_id_serialize(
            site_id=site_id,
            call_block_id=call_block_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CallBlockResponse",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_site_call_block_by_id_without_preload_content(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        call_block_id: Annotated[StrictInt, Field(description="The unique identifier of the call block rule.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Call Block Rule Details

        Retrieves detailed information for a specific call blocking rule by its ID.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param call_block_id: The unique identifier of the call block rule. (required)
        :type call_block_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_site_call_block_by_id_serialize(
            site_id=site_id,
            call_block_id=call_block_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CallBlockResponse",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_site_call_block_by_id_serialize(
        self,
        site_id,
        call_block_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['siteId'] = site_id
        if call_block_id is not None:
            _path_params['callBlockId'] = call_block_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/sites/{siteId}/call-blocks/{callBlockId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_site_call_blocks(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CallBlockListResponse:
        """List Call Block Rules for a Site

        Retrieves a list of all call blocking rules configured for the specified site.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_site_call_blocks_serialize(
            site_id=site_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CallBlockListResponse",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_site_call_blocks_with_http_info(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CallBlockListResponse]:
        """List Call Block Rules for a Site

        Retrieves a list of all call blocking rules configured for the specified site.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_site_call_blocks_serialize(
            site_id=site_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CallBlockListResponse",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_site_call_blocks_without_preload_content(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Call Block Rules for a Site

        Retrieves a list of all call blocking rules configured for the specified site.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_site_call_blocks_serialize(
            site_id=site_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CallBlockListResponse",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_site_call_blocks_serialize(
        self,
        site_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['siteId'] = site_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/sites/{siteId}/call-blocks',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_site_call_block_by_id(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        call_block_id: Annotated[StrictInt, Field(description="The unique identifier of the call block rule.")],
        call_block_update_request: Annotated[CallBlockUpdateRequest, Field(description="Call block rule attributes to update.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CallBlockResponse:
        """Update an Existing Call Block Rule

        Updates the configuration of an existing call blocking rule.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param call_block_id: The unique identifier of the call block rule. (required)
        :type call_block_id: int
        :param call_block_update_request: Call block rule attributes to update. (required)
        :type call_block_update_request: CallBlockUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_site_call_block_by_id_serialize(
            site_id=site_id,
            call_block_id=call_block_id,
            call_block_update_request=call_block_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CallBlockResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_site_call_block_by_id_with_http_info(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        call_block_id: Annotated[StrictInt, Field(description="The unique identifier of the call block rule.")],
        call_block_update_request: Annotated[CallBlockUpdateRequest, Field(description="Call block rule attributes to update.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CallBlockResponse]:
        """Update an Existing Call Block Rule

        Updates the configuration of an existing call blocking rule.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param call_block_id: The unique identifier of the call block rule. (required)
        :type call_block_id: int
        :param call_block_update_request: Call block rule attributes to update. (required)
        :type call_block_update_request: CallBlockUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_site_call_block_by_id_serialize(
            site_id=site_id,
            call_block_id=call_block_id,
            call_block_update_request=call_block_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CallBlockResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_site_call_block_by_id_without_preload_content(
        self,
        site_id: Annotated[StrictInt, Field(description="The unique identifier of the site.")],
        call_block_id: Annotated[StrictInt, Field(description="The unique identifier of the call block rule.")],
        call_block_update_request: Annotated[CallBlockUpdateRequest, Field(description="Call block rule attributes to update.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update an Existing Call Block Rule

        Updates the configuration of an existing call blocking rule.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: int
        :param call_block_id: The unique identifier of the call block rule. (required)
        :type call_block_id: int
        :param call_block_update_request: Call block rule attributes to update. (required)
        :type call_block_update_request: CallBlockUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_site_call_block_by_id_serialize(
            site_id=site_id,
            call_block_id=call_block_id,
            call_block_update_request=call_block_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CallBlockResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_site_call_block_by_id_serialize(
        self,
        site_id,
        call_block_id,
        call_block_update_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['siteId'] = site_id
        if call_block_id is not None:
            _path_params['callBlockId'] = call_block_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if call_block_update_request is not None:
            _body_params = call_block_update_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/sites/{siteId}/call-blocks/{callBlockId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from ringer_business.models.address_user_provided import AddressUserProvided
from typing import Optional, Set
from typing_extensions import Self

class CustomerRegistrationRequest(BaseModel):
    """
    Information required to register a new customer account.
    """ # noqa: E501
    name: StrictStr = Field(description="The legal name of the company or business.")
    address: AddressUserProvided
    __properties: ClassVar[List[str]] = ["name", "address"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CustomerRegistrationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CustomerRegistrationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "address": AddressUserProvided.from_dict(obj["address"]) if obj.get("address") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Ringer Business API - Call Records

    This API provides an endpoint for retrieving Call Detail Records (CDRs). Call records offer detailed information about calls made or received through the Ringer Business system, including source, destination, duration, cost, and timestamps.  Access to call records can be filtered by time range, paginated, sorted, and filtered by various call attributes. Permissions might vary; administrators may see all records for an organization, while individual users might only see their own. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from ringer_business.models.call_record import CallRecord
from ringer_business.models.link import Link
from typing import Optional, Set
from typing_extensions import Self

class CallRecordListResponse(BaseModel):
    """
    A paginated list of call records.
    """ # noqa: E501
    call_records: List[CallRecord]
    total_items: Optional[StrictInt] = Field(default=None, description="Total number of records matching the query.")
    total_pages: Optional[StrictInt] = Field(default=None, description="Total number of pages based on page_size.")
    current_page: Optional[StrictInt] = Field(default=None, description="The current page number.")
    per_page: Optional[StrictInt] = Field(default=None, description="Number of records per page.")
    links: Optional[List[Link]] = None
    __properties: ClassVar[List[str]] = ["call_records", "total_items", "total_pages", "current_page", "per_page", "links"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CallRecordListResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in call_records (list)
        _items = []
        if self.call_records:
            for _item_call_records in self.call_records:
                if _item_call_records:
                    _items.append(_item_call_records.to_dict())
            _dict['call_records'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item_links in self.links:
                if _item_links:
                    _items.append(_item_links.to_dict())
            _dict['links'] = _items
        # set to None if links (nullable) is None
        # and model_fields_set contains the field
        if self.links is None and "links" in self.model_fields_set:
            _dict['links'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CallRecordListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "call_records": [CallRecord.from_dict(_item) for _item in obj["call_records"]] if obj.get("call_records") is not None else None,
            "total_items": obj.get("total_items"),
            "total_pages": obj.get("total_pages"),
            "current_page": obj.get("current_page"),
            "per_page": obj.get("per_page"),
            "links": [Link.from_dict(_item) for _item in obj["links"]] if obj.get("links") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Ringer Business API - User Management

    This API provides endpoints for managing users within a Ringer Business account. It allows for listing users, adding new users, retrieving details of a specific user, updating user information, and deleting users.  User management operations typically require authentication and administrative privileges. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.user_create_request import UserCreateRequest

class TestUserCreateRequest(unittest.TestCase):
    """UserCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserCreateRequest:
        """Test UserCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserCreateRequest`
        """
        model = UserCreateRequest()
        if include_optional:
            return UserCreateRequest(
                first_name = 'Jane',
                last_name = 'Doe',
                email = 'jane.doe@example.com',
                role = 'user',
                active = True,
                locale = 'en-US'
            )
        else:
            return UserCreateRequest(
                first_name = 'Jane',
                last_name = 'Doe',
                email = 'jane.doe@example.com',
                role = 'user',
                active = True,
                locale = 'en-US',
        )
        """

    def testUserCreateRequest(self):
        """Test UserCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API - Packages Management

    This API provides endpoints for managing packages. Packages are collections of items or features that can be included in or added to subscription plans. This API allows retrieving details of specific packages and listing available packages.  - **Included Packages**: Provide a quantity of a specific rate item which is included in the plan subscription cost. - **Optional Packages**: Provide a quantity of a specific rate item for an additional monthly fee. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from ringer_business.models.package_feature import PackageFeature
from typing import Optional, Set
from typing_extensions import Self

class PackageCore(BaseModel):
    """
    PackageCore
    """ # noqa: E501
    id: StrictInt = Field(description="Unique identifier for the package.")
    name: StrictStr = Field(description="The name of the package.")
    description: Optional[StrictStr] = Field(default=None, description="A brief description of what the package includes or its purpose.")
    item_type: StrictStr = Field(description="The type of item this package represents or groups (e.g., subscription, feature_bundle, usage_minutes).")
    item_rules: Optional[StrictStr] = Field(default=None, description="Specific rules or subclassifications for the item type.")
    item_quantity: StrictInt = Field(description="The quantity of the item provided by this package (e.g., number of minutes, 1 for a subscription).")
    price: StrictStr = Field(description="The cost of this package if it's optional or its contribution to a plan's price.")
    currency: StrictStr = Field(description="Three-letter ISO currency code for the package price.")
    plan_id: Optional[StrictInt] = Field(default=None, description="Identifier of the plan this package definition might be primarily associated with or templated from.")
    included: StrictBool = Field(description="True if this package is an included part of a plan, false if it's optional.")
    removable: StrictBool = Field(description="Indicates if this package can be removed from a plan by the customer.")
    category: Optional[StrictStr] = Field(default=None, description="Category of the package")
    renewable: Optional[StrictBool] = Field(default=None, description="Whether the package renews automatically")
    features: Optional[List[PackageFeature]] = Field(default=None, description="List of features included in the package")
    __properties: ClassVar[List[str]] = ["id", "name", "description", "item_type", "item_rules", "item_quantity", "price", "currency", "plan_id", "included", "removable", "category", "renewable", "features"]

    @field_validator('category')
    def category_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['calling', 'messaging', 'conferencing', 'faxing', 'security', 'base_plan', 'add_on']):
            raise ValueError("must be one of enum values ('calling', 'messaging', 'conferencing', 'faxing', 'security', 'base_plan', 'add_on')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PackageCore from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in features (list)
        _items = []
        if self.features:
            for _item_features in self.features:
                if _item_features:
                    _items.append(_item_features.to_dict())
            _dict['features'] = _items
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if item_rules (nullable) is None
        # and model_fields_set contains the field
        if self.item_rules is None and "item_rules" in self.model_fields_set:
            _dict['item_rules'] = None

        # set to None if plan_id (nullable) is None
        # and model_fields_set contains the field
        if self.plan_id is None and "plan_id" in self.model_fields_set:
            _dict['plan_id'] = None

        # set to None if features (nullable) is None
        # and model_fields_set contains the field
        if self.features is None and "features" in self.model_fields_set:
            _dict['features'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PackageCore from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "item_type": obj.get("item_type"),
            "item_rules": obj.get("item_rules"),
            "item_quantity": obj.get("item_quantity"),
            "price": obj.get("price"),
            "currency": obj.get("currency") if obj.get("currency") is not None else 'USD',
            "plan_id": obj.get("plan_id"),
            "included": obj.get("included"),
            "removable": obj.get("removable"),
            "category": obj.get("category"),
            "renewable": obj.get("renewable"),
            "features": [PackageFeature.from_dict(_item) for _item in obj["features"]] if obj.get("features") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.confirmation_api import ConfirmationApi


class TestConfirmationApi(unittest.TestCase):
    """ConfirmationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConfirmationApi()

    def tearDown(self) -> None:
        pass

    def test_confirm_account(self) -> None:
        """Test case for confirm_account

        Confirm a User Account
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API - Address Management

    This API focuses on managing addresses associated with entities like customer accounts. Currently, it supports updating an existing address record linked to an account.  Address operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt
from typing_extensions import Annotated
from ringer_business.models.address_response import AddressResponse
from ringer_business.models.address_update_request import AddressUpdateRequest

from ringer_business.api_client import ApiClient, RequestSerialized
from ringer_business.api_response import ApiResponse
from ringer_business.rest import RESTResponseType


class AddressesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def update_account_address(
        self,
        address_id: Annotated[StrictInt, Field(description="The unique identifier of the address record to be updated.")],
        address_update_request: Annotated[AddressUpdateRequest, Field(description="Address attributes to update. All fields in the request are typically required for a PUT, or optional for a PATCH.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AddressResponse:
        """Update an Address

        Updates the details of a specific address record by its ID. This is typically used to modify the contact or billing address associated with an account. The user must have permissions to update the account to which this address belongs. 

        :param address_id: The unique identifier of the address record to be updated. (required)
        :type address_id: int
        :param address_update_request: Address attributes to update. All fields in the request are typically required for a PUT, or optional for a PATCH. (required)
        :type address_update_request: AddressUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_account_address_serialize(
            address_id=address_id,
            address_update_request=address_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AddressResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_account_address_with_http_info(
        self,
        address_id: Annotated[StrictInt, Field(description="The unique identifier of the address record to be updated.")],
        address_update_request: Annotated[AddressUpdateRequest, Field(description="Address attributes to update. All fields in the request are typically required for a PUT, or optional for a PATCH.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AddressResponse]:
        """Update an Address

        Updates the details of a specific address record by its ID. This is typically used to modify the contact or billing address associated with an account. The user must have permissions to update the account to which this address belongs. 

        :param address_id: The unique identifier of the address record to be updated. (required)
        :type address_id: int
        :param address_update_request: Address attributes to update. All fields in the request are typically required for a PUT, or optional for a PATCH. (required)
        :type address_update_request: AddressUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_account_address_serialize(
            address_id=address_id,
            address_update_request=address_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AddressResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_account_address_without_preload_content(
        self,
        address_id: Annotated[StrictInt, Field(description="The unique identifier of the address record to be updated.")],
        address_update_request: Annotated[AddressUpdateRequest, Field(description="Address attributes to update. All fields in the request are typically required for a PUT, or optional for a PATCH.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update an Address

        Updates the details of a specific address record by its ID. This is typically used to modify the contact or billing address associated with an account. The user must have permissions to update the account to which this address belongs. 

        :param address_id: The unique identifier of the address record to be updated. (required)
        :type address_id: int
        :param address_update_request: Address attributes to update. All fields in the request are typically required for a PUT, or optional for a PATCH. (required)
        :type address_update_request: AddressUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_account_address_serialize(
            address_id=address_id,
            address_update_request=address_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AddressResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_account_address_serialize(
        self,
        address_id,
        address_update_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if address_id is not None:
            _path_params['addressId'] = address_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if address_update_request is not None:
            _body_params = address_update_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/addresses/{addressId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Ringer Business API - Call Records

    This API provides an endpoint for retrieving Call Detail Records (CDRs). Call records offer detailed information about calls made or received through the Ringer Business system, including source, destination, duration, cost, and timestamps.  Access to call records can be filtered by time range, paginated, sorted, and filtered by various call attributes. Permissions might vary; administrators may see all records for an organization, while individual users might only see their own. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from ringer_business.models.call_record_list_response import CallRecordListResponse

from ringer_business.api_client import ApiClient, RequestSerialized
from ringer_business.api_response import ApiResponse
from ringer_business.rest import RESTResponseType


class CallRecordsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def list_call_records(
        self,
        start_time: Annotated[datetime, Field(description="Start timestamp for the query range (ISO 8601 format, e.g., \"2021-06-01T00:00:00Z\"). Maximum query window is 30 days. ")],
        page_number: Annotated[int, Field(strict=True, ge=1, description="Page number for pagination.")],
        page_size: Annotated[int, Field(le=100, strict=True, ge=1, description="Number of records per page.")],
        end_time: Annotated[Optional[datetime], Field(description="End timestamp for the query range (ISO 8601 format). Defaults to current time if omitted.")] = None,
        sort_column: Annotated[Optional[StrictStr], Field(description="Column to sort by.")] = None,
        sort_type: Annotated[Optional[StrictStr], Field(description="Sort direction.")] = None,
        filter_column: Annotated[Optional[StrictStr], Field(description="Column to filter on.")] = None,
        filter_type: Annotated[Optional[StrictStr], Field(description="Filter operator. `starts_with`, `ends_with`, `contains` only for `raw_ani` or `dni`. ")] = None,
        filter_value: Annotated[Optional[StrictStr], Field(description="Value to filter by.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CallRecordListResponse:
        """List Call Records

        Retrieves a list of Call Detail Records (CDRs) based on specified criteria. Allows for time-based querying, pagination, sorting, and filtering by call attributes like DNI, ANI, duration, etc. The scope of returned records may depend on the authenticated user's role (e.g., account admin vs. individual user). A maximum of 30 days worth of data can be queried at a time. 

        :param start_time: Start timestamp for the query range (ISO 8601 format, e.g., \"2021-06-01T00:00:00Z\"). Maximum query window is 30 days.  (required)
        :type start_time: datetime
        :param page_number: Page number for pagination. (required)
        :type page_number: int
        :param page_size: Number of records per page. (required)
        :type page_size: int
        :param end_time: End timestamp for the query range (ISO 8601 format). Defaults to current time if omitted.
        :type end_time: datetime
        :param sort_column: Column to sort by.
        :type sort_column: str
        :param sort_type: Sort direction.
        :type sort_type: str
        :param filter_column: Column to filter on.
        :type filter_column: str
        :param filter_type: Filter operator. `starts_with`, `ends_with`, `contains` only for `raw_ani` or `dni`. 
        :type filter_type: str
        :param filter_value: Value to filter by.
        :type filter_value: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_call_records_serialize(
            start_time=start_time,
            page_number=page_number,
            page_size=page_size,
            end_time=end_time,
            sort_column=sort_column,
            sort_type=sort_type,
            filter_column=filter_column,
            filter_type=filter_type,
            filter_value=filter_value,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CallRecordListResponse",
            '400': "CallRecordError",
            '401': "Error",
            '403': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_call_records_with_http_info(
        self,
        start_time: Annotated[datetime, Field(description="Start timestamp for the query range (ISO 8601 format, e.g., \"2021-06-01T00:00:00Z\"). Maximum query window is 30 days. ")],
        page_number: Annotated[int, Field(strict=True, ge=1, description="Page number for pagination.")],
        page_size: Annotated[int, Field(le=100, strict=True, ge=1, description="Number of records per page.")],
        end_time: Annotated[Optional[datetime], Field(description="End timestamp for the query range (ISO 8601 format). Defaults to current time if omitted.")] = None,
        sort_column: Annotated[Optional[StrictStr], Field(description="Column to sort by.")] = None,
        sort_type: Annotated[Optional[StrictStr], Field(description="Sort direction.")] = None,
        filter_column: Annotated[Optional[StrictStr], Field(description="Column to filter on.")] = None,
        filter_type: Annotated[Optional[StrictStr], Field(description="Filter operator. `starts_with`, `ends_with`, `contains` only for `raw_ani` or `dni`. ")] = None,
        filter_value: Annotated[Optional[StrictStr], Field(description="Value to filter by.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CallRecordListResponse]:
        """List Call Records

        Retrieves a list of Call Detail Records (CDRs) based on specified criteria. Allows for time-based querying, pagination, sorting, and filtering by call attributes like DNI, ANI, duration, etc. The scope of returned records may depend on the authenticated user's role (e.g., account admin vs. individual user). A maximum of 30 days worth of data can be queried at a time. 

        :param start_time: Start timestamp for the query range (ISO 8601 format, e.g., \"2021-06-01T00:00:00Z\"). Maximum query window is 30 days.  (required)
        :type start_time: datetime
        :param page_number: Page number for pagination. (required)
        :type page_number: int
        :param page_size: Number of records per page. (required)
        :type page_size: int
        :param end_time: End timestamp for the query range (ISO 8601 format). Defaults to current time if omitted.
        :type end_time: datetime
        :param sort_column: Column to sort by.
        :type sort_column: str
        :param sort_type: Sort direction.
        :type sort_type: str
        :param filter_column: Column to filter on.
        :type filter_column: str
        :param filter_type: Filter operator. `starts_with`, `ends_with`, `contains` only for `raw_ani` or `dni`. 
        :type filter_type: str
        :param filter_value: Value to filter by.
        :type filter_value: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_call_records_serialize(
            start_time=start_time,
            page_number=page_number,
            page_size=page_size,
            end_time=end_time,
            sort_column=sort_column,
            sort_type=sort_type,
            filter_column=filter_column,
            filter_type=filter_type,
            filter_value=filter_value,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CallRecordListResponse",
            '400': "CallRecordError",
            '401': "Error",
            '403': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_call_records_without_preload_content(
        self,
        start_time: Annotated[datetime, Field(description="Start timestamp for the query range (ISO 8601 format, e.g., \"2021-06-01T00:00:00Z\"). Maximum query window is 30 days. ")],
        page_number: Annotated[int, Field(strict=True, ge=1, description="Page number for pagination.")],
        page_size: Annotated[int, Field(le=100, strict=True, ge=1, description="Number of records per page.")],
        end_time: Annotated[Optional[datetime], Field(description="End timestamp for the query range (ISO 8601 format). Defaults to current time if omitted.")] = None,
        sort_column: Annotated[Optional[StrictStr], Field(description="Column to sort by.")] = None,
        sort_type: Annotated[Optional[StrictStr], Field(description="Sort direction.")] = None,
        filter_column: Annotated[Optional[StrictStr], Field(description="Column to filter on.")] = None,
        filter_type: Annotated[Optional[StrictStr], Field(description="Filter operator. `starts_with`, `ends_with`, `contains` only for `raw_ani` or `dni`. ")] = None,
        filter_value: Annotated[Optional[StrictStr], Field(description="Value to filter by.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Call Records

        Retrieves a list of Call Detail Records (CDRs) based on specified criteria. Allows for time-based querying, pagination, sorting, and filtering by call attributes like DNI, ANI, duration, etc. The scope of returned records may depend on the authenticated user's role (e.g., account admin vs. individual user). A maximum of 30 days worth of data can be queried at a time. 

        :param start_time: Start timestamp for the query range (ISO 8601 format, e.g., \"2021-06-01T00:00:00Z\"). Maximum query window is 30 days.  (required)
        :type start_time: datetime
        :param page_number: Page number for pagination. (required)
        :type page_number: int
        :param page_size: Number of records per page. (required)
        :type page_size: int
        :param end_time: End timestamp for the query range (ISO 8601 format). Defaults to current time if omitted.
        :type end_time: datetime
        :param sort_column: Column to sort by.
        :type sort_column: str
        :param sort_type: Sort direction.
        :type sort_type: str
        :param filter_column: Column to filter on.
        :type filter_column: str
        :param filter_type: Filter operator. `starts_with`, `ends_with`, `contains` only for `raw_ani` or `dni`. 
        :type filter_type: str
        :param filter_value: Value to filter by.
        :type filter_value: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_call_records_serialize(
            start_time=start_time,
            page_number=page_number,
            page_size=page_size,
            end_time=end_time,
            sort_column=sort_column,
            sort_type=sort_type,
            filter_column=filter_column,
            filter_type=filter_type,
            filter_value=filter_value,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CallRecordListResponse",
            '400': "CallRecordError",
            '401': "Error",
            '403': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_call_records_serialize(
        self,
        start_time,
        page_number,
        page_size,
        end_time,
        sort_column,
        sort_type,
        filter_column,
        filter_type,
        filter_value,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if start_time is not None:
            if isinstance(start_time, datetime):
                _query_params.append(
                    (
                        'start_time',
                        start_time.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('start_time', start_time))
            
        if end_time is not None:
            if isinstance(end_time, datetime):
                _query_params.append(
                    (
                        'end_time',
                        end_time.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('end_time', end_time))
            
        if page_number is not None:
            
            _query_params.append(('page[number]', page_number))
            
        if page_size is not None:
            
            _query_params.append(('page[size]', page_size))
            
        if sort_column is not None:
            
            _query_params.append(('sort[column]', sort_column))
            
        if sort_type is not None:
            
            _query_params.append(('sort[type]', sort_type))
            
        if filter_column is not None:
            
            _query_params.append(('filter[column]', filter_column))
            
        if filter_type is not None:
            
            _query_params.append(('filter[type]', filter_type))
            
        if filter_value is not None:
            
            _query_params.append(('filter[value]', filter_value))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/call-records',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Ringer Business API - Template Management

    This API provides endpoints for managing service templates within a Ringer Business account. Templates offer a pre-configured set of resources (e.g., phone numbers, devices, voicemail) that can be quickly deployed for new users or seats, ensuring consistency and simplifying setup.  Functionality includes: - Listing available templates. - Creating a new template. - Retrieving details of a specific template. - Updating an existing template. - Deleting a template. - Cloning an existing template to create a new one. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.template_list_response import TemplateListResponse

class TestTemplateListResponse(unittest.TestCase):
    """TemplateListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TemplateListResponse:
        """Test TemplateListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TemplateListResponse`
        """
        model = TemplateListResponse()
        if include_optional:
            return TemplateListResponse(
                templates = [
                    {"id":1,"name":"Sales Team Standard Setup","features":{"switchable":"PhoneNumber","position":1,"attrs":[{"name":"name","derivative":"calculated","default":"Phone Number"}]},"last_updated_by":"jane.doe@example.com","owner":"Account ABC","links":[{"href":"/templates/1","rel":"self","method":"GET"}]}
                    ],
                total_items = 56,
                total_pages = 56,
                current_page = 1,
                per_page = 25,
                links = [
                    ringer_business.models.link.Link(
                        href = '', 
                        rel = '', 
                        title = '', 
                        method = 'GET', )
                    ]
            )
        else:
            return TemplateListResponse(
                templates = [
                    {"id":1,"name":"Sales Team Standard Setup","features":{"switchable":"PhoneNumber","position":1,"attrs":[{"name":"name","derivative":"calculated","default":"Phone Number"}]},"last_updated_by":"jane.doe@example.com","owner":"Account ABC","links":[{"href":"/templates/1","rel":"self","method":"GET"}]}
                    ],
                total_items = 56,
                total_pages = 56,
                current_page = 1,
                per_page = 25,
        )
        """

    def testTemplateListResponse(self):
        """Test TemplateListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_voicemail_boxes_api import SiteFeaturesVoicemailBoxesApi


class TestSiteFeaturesVoicemailBoxesApi(unittest.TestCase):
    """SiteFeaturesVoicemailBoxesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesVoicemailBoxesApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_voicemail_box(self) -> None:
        """Test case for create_site_voicemail_box

        Create Voicemail Box for a Site
        """
        pass

    def test_list_site_available_voicemail_boxes(self) -> None:
        """Test case for list_site_available_voicemail_boxes

        List Available Voicemail Boxes for a Site
        """
        pass

    def test_list_site_voicemail_boxes(self) -> None:
        """Test case for list_site_voicemail_boxes

        List Voicemail Boxes for a Site
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SchemasPhoneNumberCore(BaseModel):
    """
    SchemasPhoneNumberCore
    """ # noqa: E501
    id: Optional[StrictInt] = Field(default=None, description="Unique identifier for the phone number record/assignment.")
    name: StrictStr = Field(description="A user-friendly name or label for the phone number (e.g., \"Main Line\", \"Sales Dept\").")
    number: StrictStr = Field(description="The actual phone number in E.164 format (e.g., +13035551212).")
    site_id: Optional[StrictInt] = Field(default=None, description="Identifier of the site the phone number is associated with. Can be null if the number is available but not yet assigned to a specific site.")
    destination_code: Optional[StrictStr] = Field(default=None, description="System code for the destination where calls to this number are routed (e.g., \"device:dev_xyz\", \"menu:ivr_main\").")
    __properties: ClassVar[List[str]] = ["id", "name", "number", "site_id", "destination_code"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SchemasPhoneNumberCore from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if site_id (nullable) is None
        # and model_fields_set contains the field
        if self.site_id is None and "site_id" in self.model_fields_set:
            _dict['site_id'] = None

        # set to None if destination_code (nullable) is None
        # and model_fields_set contains the field
        if self.destination_code is None and "destination_code" in self.model_fields_set:
            _dict['destination_code'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SchemasPhoneNumberCore from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "number": obj.get("number"),
            "site_id": obj.get("site_id"),
            "destination_code": obj.get("destination_code")
        })
        return _obj





# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_sip_trunks_api import SiteFeaturesSIPTrunksApi


class TestSiteFeaturesSIPTrunksApi(unittest.TestCase):
    """SiteFeaturesSIPTrunksApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesSIPTrunksApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_sip_trunk(self) -> None:
        """Test case for create_site_sip_trunk

        Create SIP Trunk for a Site
        """
        pass

    def test_delete_site_sip_trunk_by_id(self) -> None:
        """Test case for delete_site_sip_trunk_by_id

        Delete a SIP Trunk
        """
        pass

    def test_get_site_sip_trunk_by_id(self) -> None:
        """Test case for get_site_sip_trunk_by_id

        Get SIP Trunk Details
        """
        pass

    def test_list_site_sip_trunks(self) -> None:
        """Test case for list_site_sip_trunks

        List SIP Trunks for a Site
        """
        pass

    def test_regenerate_site_sip_trunk_password(self) -> None:
        """Test case for regenerate_site_sip_trunk_password

        Regenerate SIP Trunk Password
        """
        pass

    def test_transfer_sip_trunk(self) -> None:
        """Test case for transfer_sip_trunk

        Transfer SIP Trunk
        """
        pass

    def test_update_site_sip_trunk_by_id(self) -> None:
        """Test case for update_site_sip_trunk_by_id

        Update SIP Trunk
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.plan_core import PlanCore

class TestPlanCore(unittest.TestCase):
    """PlanCore unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlanCore:
        """Test PlanCore
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlanCore`
        """
        model = PlanCore()
        if include_optional:
            return PlanCore(
                id = 1,
                name = 'Standard Business Plan',
                description = 'Includes core calling features, 1000 domestic minutes, and basic voicemail.',
                total_cost = '49.99',
                currency = 'USD',
                removable = True,
                active = True,
                approved = True,
                finalized = True
            )
        else:
            return PlanCore(
                id = 1,
                name = 'Standard Business Plan',
                total_cost = '49.99',
                currency = 'USD',
                removable = True,
                active = True,
                approved = True,
                finalized = True,
        )
        """

    def testPlanCore(self):
        """Test PlanCore"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API - Account Management

    This API provides endpoints for managing customer accounts in the Ringer Business system. It allows for retrieving account details, updating account information, managing account status (activation/closure), and updating associated addresses.  Account operations typically require authentication and appropriate permissions (e.g., administrator role for certain updates). 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "ringer-business"
VERSION = "1.0.0"
PYTHON_REQUIRES = ">= 3.9"
REQUIRES = [
    "urllib3 >= 2.1.0, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name='ringer_ivy',
    version='1.0.4',
    description="Ringer Business API - Account Management",
    author="Ringer API Support",
    author_email="support@ringer.tel",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Ringer Business API - Account Management"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT License",
    long_description_content_type='text/markdown',
    long_description="""\
    This API provides endpoints for managing customer accounts in the Ringer Business system. It allows for retrieving account details, updating account information, managing account status (activation/closure), and updating associated addresses.  Account operations typically require authentication and appropriate permissions (e.g., administrator role for certain updates). 
    """,  # noqa: E501
    package_data={"ringer_business": ["py.typed"]},
)


# coding: utf-8

"""
    Ringer Business API - Sign Up

    This API provides the endpoint for new customers to sign up for the Ringer Business service. Successful sign-up creates a new customer account and provides a confirmation token that is typically used in a subsequent step to activate the account (see Confirmation API). 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.sign_up_api import SignUpApi


class TestSignUpApi(unittest.TestCase):
    """SignUpApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SignUpApi()

    def tearDown(self) -> None:
        pass

    def test_sign_up_customer(self) -> None:
        """Test case for sign_up_customer

        Register a new Customer Account
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from ringer_business.models.link import Link
from typing import Optional, Set
from typing_extensions import Self

class FaxMachineResponse(BaseModel):
    """
    Detailed information about a fax machine (Fax to Email) configuration.
    """ # noqa: E501
    name: StrictStr = Field(description="A user-friendly name for the fax machine configuration.")
    notification_emails: StrictStr = Field(description="Comma-separated list of email addresses to which received faxes (as PDF) will be sent.")
    user_id: Optional[StrictInt] = Field(default=None, description="Identifier of the user primarily associated with this fax machine, if any.")
    id: StrictInt = Field(description="Unique identifier for the fax machine configuration.")
    site_id: Optional[StrictInt] = Field(description="Identifier of the site this fax machine belongs to.")
    code: StrictStr = Field(description="System-level code for this fax machine, often used in routing configurations.")
    links: Optional[List[Link]] = Field(default=None, description="HATEOAS links related to this fax machine.")
    __properties: ClassVar[List[str]] = ["name", "notification_emails", "user_id", "id", "site_id", "code", "links"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FaxMachineResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "code",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item_links in self.links:
                if _item_links:
                    _items.append(_item_links.to_dict())
            _dict['links'] = _items
        # set to None if user_id (nullable) is None
        # and model_fields_set contains the field
        if self.user_id is None and "user_id" in self.model_fields_set:
            _dict['user_id'] = None

        # set to None if site_id (nullable) is None
        # and model_fields_set contains the field
        if self.site_id is None and "site_id" in self.model_fields_set:
            _dict['site_id'] = None

        # set to None if links (nullable) is None
        # and model_fields_set contains the field
        if self.links is None and "links" in self.model_fields_set:
            _dict['links'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FaxMachineResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "notification_emails": obj.get("notification_emails"),
            "user_id": obj.get("user_id"),
            "id": obj.get("id"),
            "site_id": obj.get("site_id"),
            "code": obj.get("code"),
            "links": [Link.from_dict(_item) for _item in obj["links"]] if obj.get("links") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Ringer Business API - Sign Up

    This API provides the endpoint for new customers to sign up for the Ringer Business service. Successful sign-up creates a new customer account and provides a confirmation token that is typically used in a subsequent step to activate the account (see Confirmation API). 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.address_registered import AddressRegistered

class TestAddressRegistered(unittest.TestCase):
    """AddressRegistered unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AddressRegistered:
        """Test AddressRegistered
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AddressRegistered`
        """
        model = AddressRegistered()
        if include_optional:
            return AddressRegistered(
                email = 'contact@exampleinnovations.com',
                street_address = '123 Innovation Drive, Suite 400',
                country = 'US',
                city = 'Techville',
                state_province = 'CA',
                postal_code = '90210',
                contact_number = '+18005551212',
                id = 672
            )
        else:
            return AddressRegistered(
                email = 'contact@exampleinnovations.com',
                street_address = '123 Innovation Drive, Suite 400',
                country = 'US',
                city = 'Techville',
                postal_code = '90210',
                contact_number = '+18005551212',
                id = 672,
        )
        """

    def testAddressRegistered(self):
        """Test AddressRegistered"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API - Statements

    This API provides endpoints for accessing account statements (receipts). Statements are typically generated at the end of a service interval and provide a summary of charges and payments. Developers can use this API to retrieve a list of statements or the details of a specific statement. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.statements_api import StatementsApi


class TestStatementsApi(unittest.TestCase):
    """StatementsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StatementsApi()

    def tearDown(self) -> None:
        pass

    def test_get_statement_by_id(self) -> None:
        """Test case for get_statement_by_id

        Get Statement Details
        """
        pass

    def test_list_statements(self) -> None:
        """Test case for list_statements

        List Account Statements
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CallBlockUpdateRequestDataAttributes(BaseModel):
    """
    CallBlockUpdateRequestDataAttributes
    """ # noqa: E501
    name: Optional[StrictStr] = None
    phone_number: Optional[StrictStr] = None
    direction: Optional[StrictStr] = None
    status: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["name", "phone_number", "direction", "status"]

    @field_validator('direction')
    def direction_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['inbound', 'outbound', 'both']):
            raise ValueError("must be one of enum values ('inbound', 'outbound', 'both')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['active', 'inactive']):
            raise ValueError("must be one of enum values ('active', 'inactive')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CallBlockUpdateRequestDataAttributes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if phone_number (nullable) is None
        # and model_fields_set contains the field
        if self.phone_number is None and "phone_number" in self.model_fields_set:
            _dict['phone_number'] = None

        # set to None if direction (nullable) is None
        # and model_fields_set contains the field
        if self.direction is None and "direction" in self.model_fields_set:
            _dict['direction'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CallBlockUpdateRequestDataAttributes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "phone_number": obj.get("phone_number"),
            "direction": obj.get("direction"),
            "status": obj.get("status")
        })
        return _obj





# coding: utf-8

"""
    Ringer Business API - Sign Up

    This API provides the endpoint for new customers to sign up for the Ringer Business service. Successful sign-up creates a new customer account and provides a confirmation token that is typically used in a subsequent step to activate the account (see Confirmation API). 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.customer_registration_request import CustomerRegistrationRequest

class TestCustomerRegistrationRequest(unittest.TestCase):
    """CustomerRegistrationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomerRegistrationRequest:
        """Test CustomerRegistrationRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomerRegistrationRequest`
        """
        model = CustomerRegistrationRequest()
        if include_optional:
            return CustomerRegistrationRequest(
                name = 'Example Innovations Inc.',
                address = {"email":"newuser@domain.com","street_address":"789 Startup Street","country":"US","city":"Anytown","state_province":"NY","postal_code":"10001","contact_number":"+12125550100"}
            )
        else:
            return CustomerRegistrationRequest(
                name = 'Example Innovations Inc.',
                address = {"email":"newuser@domain.com","street_address":"789 Startup Street","country":"US","city":"Anytown","state_province":"NY","postal_code":"10001","contact_number":"+12125550100"},
        )
        """

    def testCustomerRegistrationRequest(self):
        """Test CustomerRegistrationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API - Password Management

    This API provides endpoints for password management, including: - Requesting a password reset (forgot password). - Resetting the password using a token.  These operations help users regain access to their accounts if they have forgotten their password. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.forgot_password_response import ForgotPasswordResponse

class TestForgotPasswordResponse(unittest.TestCase):
    """ForgotPasswordResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ForgotPasswordResponse:
        """Test ForgotPasswordResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ForgotPasswordResponse`
        """
        model = ForgotPasswordResponse()
        if include_optional:
            return ForgotPasswordResponse(
                message = 'If an account with that email exists, a password reset link has been sent.'
            )
        else:
            return ForgotPasswordResponse(
                message = 'If an account with that email exists, a password reset link has been sent.',
        )
        """

    def testForgotPasswordResponse(self):
        """Test ForgotPasswordResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.payments_api import PaymentsApi


class TestPaymentsApi(unittest.TestCase):
    """PaymentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PaymentsApi()

    def tearDown(self) -> None:
        pass

    def test_create_payment(self) -> None:
        """Test case for create_payment

        Create a Payment
        """
        pass

    def test_list_payments(self) -> None:
        """Test case for list_payments

        List Payments
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API - Packages Management

    This API provides endpoints for managing packages. Packages are collections of items or features that can be included in or added to subscription plans. This API allows retrieving details of specific packages and listing available packages.  - **Included Packages**: Provide a quantity of a specific rate item which is included in the plan subscription cost. - **Optional Packages**: Provide a quantity of a specific rate item for an additional monthly fee. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PackageFeature(BaseModel):
    """
    PackageFeature
    """ # noqa: E501
    name: StrictStr = Field(description="Name of the feature")
    description: StrictStr = Field(description="Detailed description of the feature")
    value: Optional[StrictStr] = Field(default=None, description="Value or metric for the feature")
    __properties: ClassVar[List[str]] = ["name", "description", "value"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PackageFeature from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PackageFeature from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "value": obj.get("value")
        })
        return _obj





# coding: utf-8

"""
    Ringer Business API - Packages Management

    This API provides endpoints for managing packages. Packages are collections of items or features that can be included in or added to subscription plans. This API allows retrieving details of specific packages and listing available packages.  - **Included Packages**: Provide a quantity of a specific rate item which is included in the plan subscription cost. - **Optional Packages**: Provide a quantity of a specific rate item for an additional monthly fee. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List
from ringer_business.models.package_response import PackageResponse
from typing import Optional, Set
from typing_extensions import Self

class CategorizedPackageListResponse(BaseModel):
    """
    A list of packages, typically categorized into included and optional. (Used by Plans API)
    """ # noqa: E501
    included_packages: List[PackageResponse] = Field(description="Packages that are automatically part of a plan.")
    optional_packages: List[PackageResponse] = Field(description="Additional packages that can be added to a plan.")
    __properties: ClassVar[List[str]] = ["included_packages", "optional_packages"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CategorizedPackageListResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in included_packages (list)
        _items = []
        if self.included_packages:
            for _item_included_packages in self.included_packages:
                if _item_included_packages:
                    _items.append(_item_included_packages.to_dict())
            _dict['included_packages'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in optional_packages (list)
        _items = []
        if self.optional_packages:
            for _item_optional_packages in self.optional_packages:
                if _item_optional_packages:
                    _items.append(_item_optional_packages.to_dict())
            _dict['optional_packages'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CategorizedPackageListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "included_packages": [PackageResponse.from_dict(_item) for _item in obj["included_packages"]] if obj.get("included_packages") is not None else None,
            "optional_packages": [PackageResponse.from_dict(_item) for _item in obj["optional_packages"]] if obj.get("optional_packages") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_fax_machines_api import SiteFeaturesFaxMachinesApi


class TestSiteFeaturesFaxMachinesApi(unittest.TestCase):
    """SiteFeaturesFaxMachinesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesFaxMachinesApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_fax_machine(self) -> None:
        """Test case for create_site_fax_machine

        Create a Fax Machine for a Site
        """
        pass

    def test_delete_site_fax_machine_by_id(self) -> None:
        """Test case for delete_site_fax_machine_by_id

        Delete a Fax Machine Configuration
        """
        pass

    def test_get_site_fax_machine_by_id(self) -> None:
        """Test case for get_site_fax_machine_by_id

        Get Fax Machine Details
        """
        pass

    def test_list_site_available_fax_machines(self) -> None:
        """Test case for list_site_available_fax_machines

        List Available Fax Machines for a Site/User
        """
        pass

    def test_list_site_fax_machines(self) -> None:
        """Test case for list_site_fax_machines

        List Fax Machines for a Site
        """
        pass

    def test_transfer_fax_machine_to_new_site(self) -> None:
        """Test case for transfer_fax_machine_to_new_site

        Transfer Fax Machine to Another Site
        """
        pass

    def test_update_site_fax_machine_by_id(self) -> None:
        """Test case for update_site_fax_machine_by_id

        Update Fax Machine Configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API - Phone Number Management

    This API provides endpoints for managing phone numbers within a Ringer Business account and its sites. Phone numbers are essential for making and receiving calls and can be routed to various features like devices, menus, or voicemail.  Functionality includes: - Listing phone numbers associated with a specific site. - Assigning (creating) a new phone number to a site. - Retrieving details of a specific phone number. - Updating a phone number's configuration (e.g., its routing destination). - Deleting/unassigning a phone number from a site. - Transferring a phone number between sites. - Listing available phone numbers for assignment to a site (from inventory or search). - Searching for available phone numbers based on criteria like area code, city, etc. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.phone_number_availability import PhoneNumberAvailability

class TestPhoneNumberAvailability(unittest.TestCase):
    """PhoneNumberAvailability unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PhoneNumberAvailability:
        """Test PhoneNumberAvailability
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PhoneNumberAvailability`
        """
        model = PhoneNumberAvailability()
        if include_optional:
            return PhoneNumberAvailability(
                number = '+13035551234',
                location = 'Denver, CO',
                type = 'local',
                features = ["voice","sms"]
            )
        else:
            return PhoneNumberAvailability(
                number = '+13035551234',
        )
        """

    def testPhoneNumberAvailability(self):
        """Test PhoneNumberAvailability"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
